@@ -1,6 +1,7 @@
 from lmdbm import Lmdb
 from pathlib import Path
 from typing import TypeVar, Union
+import uuid
 
 from .types import int_t
 
@@ -8,16 +9,16 @@ T = TypeVar("T")
 
 class DbFactory:
     """
-    A factory for creating LMDB-backed databases of FASTA entries.
+    A wrapper around lmdbm.Lmdb that allows for buffered writes.
     """
     def __init__(self, path: Union[str, Path], chunk_size: int_t = 10000):
         self.path = Path(path)
-        if self.path.suffix != ".db":
-            self.path = Path(str(self.path) + ".db")
         self.db = Lmdb.open(str(self.path), "n", lock=True)
         self.buffer: dict[Union[str, bytes], bytes] = {}
         self.chunk_size = chunk_size
         self.is_closed = False
+        self.uuid = uuid.uuid4()
+        self.write("uuid", self.uuid.bytes)
 
     def flush(self):
         self.db.update(self.buffer)
@@ -43,9 +44,9 @@ class DbFactory:
     def close(self):
         if self.is_closed:
             return
+        self.is_closed = True
         self.before_close()
         self.db.close()
-        self.is_closed = True
 
     def __enter__(self):
         return self
@@ -58,26 +59,34 @@ class DbFactory:
 
 
 class DbWrapper:
-    __slots__ = ("__path", "__db", "__is_closed")
+    __slots__ = ("_path", "_db", "_is_closed", "_uuid")
 
     def __init__(self, path: Union[str, Path]):
-        self.__path = Path(path).absolute()
-        self.__db = Lmdb.open(str(path), lock=False)
-        self.__is_closed = False
+        self._path = Path(path).absolute()
+        self._db = Lmdb.open(str(path), lock=False)
+        self._is_closed = False
+        try:
+            self._uuid = uuid.UUID(bytes=self.db["uuid"])
+        except KeyError:
+            raise Exception(f"Database at {self.path} does not have a UUID.")
 
     def close(self):
-        if self.__is_closed:
+        if self._is_closed:
             return
-        self.__is_closed = True
-        return self.__db.close()
+        self._is_closed = True
+        return self._db.close()
 
     @property
     def db(self) -> Lmdb:
-        return self.__db
+        return self._db
 
     @property
     def path(self) -> Path:
-        return self.__path
+        return self._path
+
+    @property
+    def uuid(self) -> uuid.UUID:
+        return self._uuid
 
     def __enter__(self):
         return self
